{ config, lib, pkgs, modulesPath, ... }:

{
  imports = [
    (modulesPath + "/profiles/qemu-guest.nix")
  ];

  boot = {
    kernelParams = [ "ip=dhcp" ];
    initrd = {
      availableKernelModules = [
        "aes_neon_blk"
        "aes_neon_bs"
        "ahci"
        "sr_mod"
        "usbhid"
        "virtio_pci"
        "virtio_scsi"
        "xhci_pci"
      ];
      network.enable = true; # remote unlocking
      luks.devices."root".device = "/dev/disk/by-uuid/dd131862-29a2-4464-8c7c-5a3fd1bab8ff";
    };
    loader = {
      grub.enable = false;
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
  };

  fileSystems = {
    "/" = {
      device = "/dev/disk/by-uuid/31412044-8ef5-4f02-bbda-55af44e344cc";
      fsType = "btrfs";
      options = [ "compress=zstd" "ssd" ];
    };
    "/boot" = {
      device = "/dev/disk/by-uuid/40F5-721A";
      fsType = "vfat";
    };
  };

  networking.useDHCP = false;
  networking.usePredictableInterfaceNames = false;
  systemd.network = {
    enable = true;
    networks = {
      eth0 = {
        name = "eth0";
        DHCP = "yes";
        domains = [ "sbruder.de" ];
        address = [ "2a03:4000:6b:d2::1/64" ];
        gateway = [ "fe80::1" ];
      };
    };
  };

  # no smart on qemu disk
  services.smartd.enable = false;
}
